@@ -6,6 +6,11 @@ import alphaconf
 import alphaconf.logging_util
 
 
+@pytest.fixture(scope='function')
+def application():
+    return alphaconf.Application(name='test_logging')
+
+
 @pytest.fixture(scope='function')
 def log(application):
     application.setup_configuration(arguments=False, setup_logging=True)
